==> zio-aws-sagemaker_3-5.20.22.2-sources.jar: zio/aws/sagemaker/model/ListModelCardVersionsRequest.scala <==
package zio.aws.sagemaker.model
import zio.aws.sagemaker.model.primitives.{
  NextToken,
  EntityName,
  MaxResults,
  Timestamp
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListModelCardVersionsRequest(
    creationTimeAfter: Optional[Timestamp] = Optional.Absent,
    creationTimeBefore: Optional[Timestamp] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent,
    modelCardName: EntityName,
    modelCardStatus: Optional[zio.aws.sagemaker.model.ModelCardStatus] =
      Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent,
    sortBy: Optional[zio.aws.sagemaker.model.ModelCardVersionSortBy] =
      Optional.Absent,
    sortOrder: Optional[zio.aws.sagemaker.model.ModelCardSortOrder] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.ListModelCardVersionsRequest = {
    import ListModelCardVersionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.ListModelCardVersionsRequest
      .builder()
      .optionallyWith(
        creationTimeAfter.map(value => Timestamp.unwrap(value): Instant)
      )(_.creationTimeAfter)
      .optionallyWith(
        creationTimeBefore.map(value => Timestamp.unwrap(value): Instant)
      )(_.creationTimeBefore)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .modelCardName(EntityName.unwrap(modelCardName): java.lang.String)
      .optionallyWith(modelCardStatus.map(value => value.unwrap))(
        _.modelCardStatus
      )
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(sortBy.map(value => value.unwrap))(_.sortBy)
      .optionallyWith(sortOrder.map(value => value.unwrap))(_.sortOrder)
      .build()
  }
  def asReadOnly
      : zio.aws.sagemaker.model.ListModelCardVersionsRequest.ReadOnly =
    zio.aws.sagemaker.model.ListModelCardVersionsRequest.wrap(buildAwsValue())
}
object ListModelCardVersionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.ListModelCardVersionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.ListModelCardVersionsRequest =
      zio.aws.sagemaker.model.ListModelCardVersionsRequest(
        creationTimeAfter.map(value => value),
        creationTimeBefore.map(value => value),
        maxResults.map(value => value),
        modelCardName,
        modelCardStatus.map(value => value),
        nextToken.map(value => value),
        sortBy.map(value => value),
        sortOrder.map(value => value)
      )
    def creationTimeAfter: Optional[Timestamp]
    def creationTimeBefore: Optional[Timestamp]
    def maxResults: Optional[MaxResults]
    def modelCardName: EntityName
    def modelCardStatus: Optional[zio.aws.sagemaker.model.ModelCardStatus]
    def nextToken: Optional[NextToken]
    def sortBy: Optional[zio.aws.sagemaker.model.ModelCardVersionSortBy]
    def sortOrder: Optional[zio.aws.sagemaker.model.ModelCardSortOrder]
    def getCreationTimeAfter: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("creationTimeAfter", creationTimeAfter)
    def getCreationTimeBefore: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("creationTimeBefore", creationTimeBefore)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getModelCardName: ZIO[Any, Nothing, EntityName] =
      ZIO.succeed(modelCardName)
    def getModelCardStatus
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.ModelCardStatus] =
      AwsError.unwrapOptionField("modelCardStatus", modelCardStatus)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getSortBy
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.ModelCardVersionSortBy] =
      AwsError.unwrapOptionField("sortBy", sortBy)
    def getSortOrder
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.ModelCardSortOrder] =
      AwsError.unwrapOptionField("sortOrder", sortOrder)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.ListModelCardVersionsRequest
  ) extends zio.aws.sagemaker.model.ListModelCardVersionsRequest.ReadOnly {
    override val creationTimeAfter: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.creationTimeAfter())
      .map(value => zio.aws.sagemaker.model.primitives.Timestamp(value))
    override val creationTimeBefore: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.creationTimeBefore())
      .map(value => zio.aws.sagemaker.model.primitives.Timestamp(value))
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.sagemaker.model.primitives.MaxResults(value))
    override val modelCardName: EntityName =
      zio.aws.sagemaker.model.primitives.EntityName(impl.modelCardName())
    override val modelCardStatus
        : Optional[zio.aws.sagemaker.model.ModelCardStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.modelCardStatus())
        .map(value => zio.aws.sagemaker.model.ModelCardStatus.wrap(value))
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.sagemaker.model.primitives.NextToken(value))
    override val sortBy
        : Optional[zio.aws.sagemaker.model.ModelCardVersionSortBy] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sortBy())
        .map(value =>
          zio.aws.sagemaker.model.ModelCardVersionSortBy.wrap(value)
        )
    override val sortOrder
        : Optional[zio.aws.sagemaker.model.ModelCardSortOrder] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sortOrder())
        .map(value => zio.aws.sagemaker.model.ModelCardSortOrder.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.ListModelCardVersionsRequest
  ): zio.aws.sagemaker.model.ListModelCardVersionsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-sagemaker_3-7.21.15.7-sources.jar: zio/aws/sagemaker/model/ListModelCardVersionsRequest.scala <==
package zio.aws.sagemaker.model
import zio.aws.sagemaker.model.primitives.{
  NextToken,
  ModelCardNameOrArn,
  MaxResults,
  Timestamp
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListModelCardVersionsRequest(
    creationTimeAfter: Optional[Timestamp] = Optional.Absent,
    creationTimeBefore: Optional[Timestamp] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent,
    modelCardName: ModelCardNameOrArn,
    modelCardStatus: Optional[zio.aws.sagemaker.model.ModelCardStatus] =
      Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent,
    sortBy: Optional[zio.aws.sagemaker.model.ModelCardVersionSortBy] =
      Optional.Absent,
    sortOrder: Optional[zio.aws.sagemaker.model.ModelCardSortOrder] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.ListModelCardVersionsRequest = {
    import ListModelCardVersionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.ListModelCardVersionsRequest
      .builder()
      .optionallyWith(
        creationTimeAfter.map(value => Timestamp.unwrap(value): Instant)
      )(_.creationTimeAfter)
      .optionallyWith(
        creationTimeBefore.map(value => Timestamp.unwrap(value): Instant)
      )(_.creationTimeBefore)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .modelCardName(ModelCardNameOrArn.unwrap(modelCardName): java.lang.String)
      .optionallyWith(modelCardStatus.map(value => value.unwrap))(
        _.modelCardStatus
      )
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(sortBy.map(value => value.unwrap))(_.sortBy)
      .optionallyWith(sortOrder.map(value => value.unwrap))(_.sortOrder)
      .build()
  }
  def asReadOnly
      : zio.aws.sagemaker.model.ListModelCardVersionsRequest.ReadOnly =
    zio.aws.sagemaker.model.ListModelCardVersionsRequest.wrap(buildAwsValue())
}
object ListModelCardVersionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.ListModelCardVersionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.ListModelCardVersionsRequest =
      zio.aws.sagemaker.model.ListModelCardVersionsRequest(
        creationTimeAfter.map(value => value),
        creationTimeBefore.map(value => value),
        maxResults.map(value => value),
        modelCardName,
        modelCardStatus.map(value => value),
        nextToken.map(value => value),
        sortBy.map(value => value),
        sortOrder.map(value => value)
      )
    def creationTimeAfter: Optional[Timestamp]
    def creationTimeBefore: Optional[Timestamp]
    def maxResults: Optional[MaxResults]
    def modelCardName: ModelCardNameOrArn
    def modelCardStatus: Optional[zio.aws.sagemaker.model.ModelCardStatus]
    def nextToken: Optional[NextToken]
    def sortBy: Optional[zio.aws.sagemaker.model.ModelCardVersionSortBy]
    def sortOrder: Optional[zio.aws.sagemaker.model.ModelCardSortOrder]
    def getCreationTimeAfter: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("creationTimeAfter", creationTimeAfter)
    def getCreationTimeBefore: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("creationTimeBefore", creationTimeBefore)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getModelCardName: ZIO[Any, Nothing, ModelCardNameOrArn] =
      ZIO.succeed(modelCardName)
    def getModelCardStatus
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.ModelCardStatus] =
      AwsError.unwrapOptionField("modelCardStatus", modelCardStatus)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getSortBy
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.ModelCardVersionSortBy] =
      AwsError.unwrapOptionField("sortBy", sortBy)
    def getSortOrder
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.ModelCardSortOrder] =
      AwsError.unwrapOptionField("sortOrder", sortOrder)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.ListModelCardVersionsRequest
  ) extends zio.aws.sagemaker.model.ListModelCardVersionsRequest.ReadOnly {
    override val creationTimeAfter: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.creationTimeAfter())
      .map(value => zio.aws.sagemaker.model.primitives.Timestamp(value))
    override val creationTimeBefore: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.creationTimeBefore())
      .map(value => zio.aws.sagemaker.model.primitives.Timestamp(value))
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.sagemaker.model.primitives.MaxResults(value))
    override val modelCardName: ModelCardNameOrArn =
      zio.aws.sagemaker.model.primitives
        .ModelCardNameOrArn(impl.modelCardName())
    override val modelCardStatus
        : Optional[zio.aws.sagemaker.model.ModelCardStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.modelCardStatus())
        .map(value => zio.aws.sagemaker.model.ModelCardStatus.wrap(value))
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.sagemaker.model.primitives.NextToken(value))
    override val sortBy
        : Optional[zio.aws.sagemaker.model.ModelCardVersionSortBy] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sortBy())
        .map(value =>
          zio.aws.sagemaker.model.ModelCardVersionSortBy.wrap(value)
        )
    override val sortOrder
        : Optional[zio.aws.sagemaker.model.ModelCardSortOrder] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sortOrder())
        .map(value => zio.aws.sagemaker.model.ModelCardSortOrder.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.ListModelCardVersionsRequest
  ): zio.aws.sagemaker.model.ListModelCardVersionsRequest.ReadOnly =
    new Wrapper(impl)
}
